@@ -85,6 +85,10 @@ class Agent(pg.sprite.Sprite):
     def _find_path(self, start, end):
         return self.simulation.path_finder.find_path(start, end)
 
+    @property
+    def birthday(self):
+        return self._birthday
+
     @property
     def health_state(self):
         return self._health_state
@@ -95,6 +99,13 @@ class Agent(pg.sprite.Sprite):
         Agent.health_counts[hs.value] += 1
         self._health_state = hs
         self.image.fill(health_colors[hs.value])
+        if (hs == HealthState.INFECTED):
+            self.simulation.infected_today += 1
+        elif (hs == HealthState.DEAD):
+            self.simulation.kill_agent()
+        elif (hs == HealthState.IMMUNE):
+            self.simulation.immunize_agent()
+
 
     @property
     def inside(self):
@@ -193,7 +204,7 @@ class Agent(pg.sprite.Sprite):
                     else:
                         self.simulation.buildings[current_visit[0]].add_agent(self)
                 except Exception:
-                    print("YOU FUCKED UP")
+                    print("Exception")
             return
 
 
