@@ -18,6 +18,7 @@ from sickulator.settings import DAY_LENGTH, NIGHT_LENGTH
 
 class Simulation:
     def __init__(self, game):
+        Agent.health_counts = [0,0,0,0]
         self.game = game
         self.screen = game.screen
         self.load_data()
@@ -28,9 +29,14 @@ class Simulation:
         self.simulation_settings = game.simulation_settings
         self.multiplier = 1
         self.show_popup = False
-        self.result_data = [[0, 0, 0, 0]]
+        self.show_sprite_popup = False
+        self.selected_sprite = None
+        self.selected_label = None
+        self.daily_stats = []  # [Healthy, Infected, Immune, Dead]
+        self.cumulative_stats = [0,0,0,10] # [Total Killed, Total Immune, Total Infected, Total agents]
         self.path_finder = PathFinder(self.grid)
         self.isDaytime = True
+        self.infected_today = 0
         self.new()
 
     def enable_popup(self):
@@ -61,7 +67,7 @@ class Simulation:
         self.homes = []  # create_homes from buildings; better suited here
         for x in range(0, len(home_addresses) - 1):
             new_building = Building(
-                int(home_addresses[x][0]), int(home_addresses[x][1]), "inside", x, self.simulation_settings
+                int(home_addresses[x][0]), int(home_addresses[x][1]), home_rectangles[x], "inside", x, self
             )
             self.homes.append(new_building)
 
@@ -74,9 +80,10 @@ class Simulation:
                     Building(
                         int(building_addresses[x][0]),
                         int(building_addresses[x][1]),
+                        building_rectangles[x],
                         "inside",
                         x,
-                        self.simulation_settings
+                        self
                     )
                 )
             else:
@@ -84,9 +91,10 @@ class Simulation:
                     Building(
                         int(building_addresses[x][0]),
                         int(building_addresses[x][1]),
+                        building_rectangles[x],
                         "outside",
                         x,
-                        self.simulation_settings
+                        self
                     )
                 )
 
@@ -209,7 +217,7 @@ class Simulation:
 
         self.status = pygame_gui.elements.UITextBox(
             relative_rect=pg.Rect((0, 550), (300, 200)),
-            html_text=f"""<body>Healthy:  {Agent.health_counts[0]}<br>Infected: {Agent.health_counts[1]}<br>Immune:   {Agent.health_counts[2]}<br>Dead:     {Agent.health_counts[3]}</body>""",
+            html_text=f"""<body></body>""",
             container=self.info,
             manager=self.gui,
             layer_starting_height=2,
@@ -222,6 +230,30 @@ class Simulation:
             text="End Simulation",
         )
 
+        self.sprite_status = pygame_gui.elements.UIPanel(
+            relative_rect=pg.Rect((WIDTH - 180, 200), (150, 150)),
+            starting_layer_height=0,
+            manager=self.gui,
+            visible=False
+        )
+
+        self.sprite_description = pygame_gui.elements.UITextBox(
+            html_text=f"""<body>Healthy:  {Agent.health_counts[0]}<br>Infected: {Agent.health_counts[1]}</body>""",
+            relative_rect=pg.Rect((0, 0), (150, 150)),
+            container=self.sprite_status,
+            manager=self.gui,
+            layer_starting_height=2,
+        )
+
+        self.sprite_close_button = pygame_gui.elements.UIButton(
+            relative_rect=pg.Rect((150-30,0), (30, 30)),
+            text="X",
+            manager=self.gui,
+            container=self.sprite_status,
+            visible=False,
+            starting_height=3
+        )
+
     def toggle_info(self, val):
         self.show_popup = val
         self.info.visible = val
@@ -229,6 +261,25 @@ class Simulation:
         self.description.visible = val
         self.status.visible = val
 
+    def toggle_sprite_status(self, val):
+        self.show_sprite_popup = val
+        self.sprite_status.visible = val
+        self.sprite_description.visible = val
+        self.sprite_close_button.visible = val
+
+    def update_sprite_status(self):
+        d = {}
+        if (self.selected_label == 'building' or self.selected_label == 'building'):
+            d = {'Visitors' : len(self.selected_sprite.agents), "Infected" : self.selected_sprite.infected_count}
+        elif (self.selected_label == "agent"):
+            states = ["Healthy","Infected","Immune","Dead"]
+            d = {'Status' : states[self.selected_sprite.health_state.value], 'Birthday' : self.selected_sprite.birthday}
+        details = ""
+        for key, val in d.items():
+            details += f"{key}: {val}<br>"
+        self.sprite_description.html_text = f"<body>{details}</body>"
+        self.sprite_description.rebuild()
+
     def update_status(self):
         self.status.html_text = f"""<body>Healthy:  {Agent.health_counts[0]}<br>Infected: {Agent.health_counts[1]}<br>Immune:   {Agent.health_counts[2]}<br>Dead:     {Agent.health_counts[3]}</body>"""
         self.status.rebuild()  #  This might not be proper
@@ -238,7 +289,7 @@ class Simulation:
         self.playing = True
         self.time = 0
         self.day_duration = 0
-        self.result_data.append(Agent.health_counts)
+        self.daily_stats.append(Agent.health_counts.copy())
         while self.playing:
             self.dt = (self.clock.tick(FPS) / 1000) * self.multiplier
             self.time += self.dt
@@ -256,16 +307,18 @@ class Simulation:
         if self.day_duration >= DAY_LENGTH:
             # Change to new day
             if self.day_duration >= DAY_LENGTH + NIGHT_LENGTH:
+                self.cumulative_stats[2] += self.infected_today
+                self.infected_today = 0
                 self.isDaytime = True
                 self.day += 1
                 self.day_duration = 0
                 if self.day > self.simulation_settings.simulation_duration:
                     self.end_game()
                 self.timer.set_text("Day: " + str(self.day))
-                self.result_data.append(Agent.health_counts)
                 generate_schedules(self.agents)
                 for agent in self.agents:
                     agent.daily_update()
+                self.daily_stats.append(Agent.health_counts.copy())
             # Day changes to night
             if self.isDaytime:
                 self.isDaytime = False
@@ -274,6 +327,8 @@ class Simulation:
         self.camera.update(self.player)
         if self.show_popup:
             self.update_status()
+        if self.show_sprite_popup:
+            self.update_sprite_status()
 
     def events(self):
         # catch all events here
@@ -287,6 +342,8 @@ class Simulation:
                         self.toggle_info(True)
                     elif event.ui_element == self.close_button:
                         self.toggle_info(False)
+                    elif event.ui_element == self.sprite_close_button:
+                        self.toggle_sprite_status(False)
                     elif event.ui_element == self.half_speed_button:
                         self.half_speed_button.set_text("*0.5x*")
                         self.normal_speed_button.set_text("1x")
@@ -313,6 +370,30 @@ class Simulation:
                     self.playing = False
                     pg.quit()
                     sys.exit()
+            if event.type == pg.MOUSEBUTTONUP:
+                pos = pg.mouse.get_pos()
+                # get a list of all sprites that are under the mouse cursor
+                clicked_agents = [s for s in self.agents if s.rect.collidepoint(pos)]
+                if len(clicked_agents) > 0:
+                    agent = clicked_agents[0]
+                    self.selected_label = "agent"
+                    self.selected_sprite = agent
+                    self.toggle_sprite_status(True)
+                else:
+                    clicked_buildings = [s for s in self.buildings if s.rect.collidepoint(pos)]
+                    if len(clicked_buildings) > 0:
+                        building = clicked_buildings[0]
+                        self.selected_label = "building"
+                        self.selected_sprite = building
+                        self.toggle_sprite_status(True)
+                    else:
+                        clicked_homes = [s for s in self.homes if s.rect.collidepoint(pos)]
+                        if len(clicked_homes) > 0:
+                            home = clicked_homes[0]
+                            self.selected_label = "home"
+                            self.selected_sprite = home
+                            self.toggle_sprite_status(True)
+
         return events
 
     def draw_grid(self):
@@ -331,7 +412,7 @@ class Simulation:
 
     def end_game(self):
         self.playing = False
-        self.game.end_simulation(self.result_data)
+        self.game.end_simulation(self.daily_stats,self.cumulative_stats)
 
     def quit(self):
         pg.quit()
@@ -348,3 +429,13 @@ class Simulation:
                     grid[y][x] = gid
 
         return grid
+
+    def spawn_agent(self):
+        self.cumulative_stats[3] = self.cumulative_stats[3] + 1
+
+    def kill_agent(self):
+        '''Gets called when agent dies to disease'''
+        self.cumulative_stats[0] = self.cumulative_stats[0] + 1
+
+    def immunize_agent(self):
+        self.cumulative_stats[1] = self.cumulative_stats[1] + 1
\ No newline at end of file
